/*
*
* Copyright (c) 2005 Sun Microsystems, Inc.
* All rights reserved.
* You may not modify, use, reproduce, or distribute this software except in compliance with the terms
* of the License at: http://developer.sun.com/berkeley_license.html
* Author : Sameer Tyagi, Sun Microsystems s.t@sun.com
* "Realizing Strategies for Document-Based Web Services With JAX-WS 2.0"
*  http://java.sun.com/developer/technicalArticles/xml/jaxrpcpatterns
*/
import com.examples.docliteral.clientbindings.*;
import com.examples.docliteral.clientbindings.PurchaseOrderService;
import com.examples.docliteral.clientbindings.POProcessingProblem;
import com.examples.docliteral.*;

import javax.xml.ws.BindingProvider;
import javax.xml.datatype.DatatypeFactory;
import javax.xml.datatype.XMLGregorianCalendar;
import java.util.Calendar;
import java.util.GregorianCalendar;
import java.math.BigDecimal;


public class WSDLClient {

    public static void main(String[] args) throws Exception {
        String url = "http://localhost:9090/docliteralfromjava-war/jaxws";
        if (args.length == 1) {
            url = args[0];
        }
      POService serviceproxy = new POService();
	    PurchaseOrderService stub = serviceproxy.getIPurchaseOrderPort()	;
		   ((BindingProvider) stub).getRequestContext().put(
                BindingProvider.ENDPOINT_ADDRESS_PROPERTY, url);
        sendPurchaseOrder(stub);
    }


    /**
     * Sends a purchaseorder to the service
     *
     * @param stub
     * @throws java.rmi.RemoteException
     */
    private static void sendPurchaseOrder(PurchaseOrderService stub) throws Exception {

        Address addrs = new Address();
        addrs.setAddress("1 Main Street");
        addrs.setCity( "Beverly Hills");
        addrs.setState("CA");
        addrs.setZipCode("90210");

        LineItem item1= new LineItem();
        item1.setName("Copier Paper");
        item1.setPrice( new BigDecimal(10.00));
        item1.setQuantity(2);

        LineItem item2= new LineItem();
        item2.setName("Toner");
        item2.setPrice( new BigDecimal(920.00));
        item2.setQuantity(1);


        PurchaseOrder order = new PurchaseOrder();

               DatatypeFactory df= DatatypeFactory.newInstance();
            XMLGregorianCalendar xmlcal = df.newXMLGregorianCalendar(new GregorianCalendar());


        order.setCreateDate(xmlcal);
        order.setBillTo(addrs);
        order.setShipTo(addrs);
        order.getItems().add(item1);
        order.getItems().add(item2);
        order.setPoID("ABC-CO-19282");

        try {
            PurchaseOrderStatus result = stub.acceptPO(order);
            System.out.println("Order id is : " + result.getOrderid());
            System.out.println("Timestamp is : " + result.getTimestamp());
        } catch (POProcessingProblem e1) {
            System.out.println("Problem processing PO on the web service : " + e1);
        }
    }


}
